@@ -13,9 +13,9 @@ from functools import partial
 import numpy
 import pandas
 
-from draugr import indent_lines
 from draugr.pandas_utilities.formatting import pandas_mean_std_bold_formatter
 from warg import Number, drop_unused_kws, passes_kws_to
+from warg import indent_lines
 
 __all__ = [
     "pandas_mean_std",
