@@ -12,7 +12,7 @@ from typing import Tuple, Union
 
 __all__ = ["transp_conv2d_output_shape", "transp_conv2d_padding_sizes"]
 
-from draugr import replicate
+from warg import replicate
 
 
 def transp_conv2d_output_shape(
