@@ -14,13 +14,12 @@ from matplotlib.figure import Figure
 from draugr import PROJECT_APP_PATH
 from draugr.numpy_utilities.mixing import mix_channels
 from draugr.opencv_utilities import draw_masks
-from draugr.python_utilities import sprint
-from draugr.torch_utilities.tensors.to_tensor import to_tensor
-from draugr.torch_utilities.writers.mixins.graph_writer_mixin import GraphWriterMixin
 from draugr.torch_utilities.tensors.dimension_order import (
     nhwc_to_nchw_tensor,
     nthwc_to_ntchw_tensor,
 )
+from draugr.torch_utilities.tensors.to_tensor import to_tensor
+from draugr.torch_utilities.writers.mixins.graph_writer_mixin import GraphWriterMixin
 from draugr.torch_utilities.writers.torch_module_writer.module_parameter_writer_mixin import (
     ModuleParameterWriterMixin,
 )
@@ -45,6 +44,7 @@ from draugr.writers.mixins.precision_recall_writer_mixin import (
 from draugr.writers.mixins.spectrogram_writer_mixin import SpectrogramWriterMixin
 from draugr.writers.writer import Writer
 from warg import drop_unused_kws, passes_kws_to
+from warg import sprint
 
 with suppress(FutureWarning):
     from torch.utils.tensorboard import SummaryWriter
@@ -449,6 +449,7 @@ pyplot.title(tag)
         model: torch.nn.Module,
         input_to_model: torch.Tensor,
         verbose: bool = False,
+        use_strict_trace: bool = True,
     ) -> None:
         """
 
@@ -457,7 +458,9 @@ pyplot.title(tag)
         :type model:
         :param input_to_model:
         :type input_to_model:"""
-        self.writer.add_graph(model, input_to_model, verbose)
+        self.writer.add_graph(
+            model, input_to_model, verbose=verbose, use_strict_trace=use_strict_trace
+        )
 
     def _close(self, exc_type=None, exc_val=None, exc_tb=None):
         if hasattr(self, "_writer"):
