@@ -48,7 +48,19 @@ __all__ = [
 def correlation_matrix_plot(
     cor: Sequence, labels: Sequence = None, title: str = "", **kwargs
 ) -> Figure:
-    """ """
+    """
+
+    :param cor:
+    :type cor:
+    :param labels:
+    :type labels:
+    :param title:
+    :type title:
+    :param kwargs:
+    :type kwargs:
+    :return:
+    :rtype:
+    """
     if labels is None:
         labels = [f"P{i}" for i in range(len(cor))]
 
@@ -466,8 +478,10 @@ def confusion_matrix_plot(
 
 if __name__ == "__main__":
 
-    def a():
-        """ """
+    def a() -> None:
+        """
+        :rtype: None
+        """
         from sklearn import datasets
 
         iris = datasets.load_iris()
